/*
 * Copyright 2000-2004 by Hans Reiser, licensing governed by 
 * reiserfsprogs/README
 */

#include "resize.h"

/* the front-end for kernel on-line resizer */
int resize_fs_online(char * devname, long long int blocks) {
	struct mntent *mnt;
	char buf[40];
	
	/* Find the mount entry. */
	if ((mnt = misc_mntent(devname)) == NULL)
		die ("resize_reiserfs: can't find mount entry\n");

	sprintf(buf,"resize=%lld", blocks);

	if (mount(mnt->mnt_fsname, mnt->mnt_dir, mnt->mnt_type,
		  (unsigned long)(MS_MGC_VAL8tdQVUsãݴ'Jgf8]&,ar$S_X_T0#4++6sQctu:EZ֋Ʋ1?9ςz6j݉Hb6/